@@ -15,7 +15,7 @@ class Order:
                  canal_id: int, transportadora_id: str, transportadora: str, servico_id: int, servico: str,
                  codigo_carga: str, protocolo: str, transacao, usuario: dict, pagamento: list, itens: list,
                  itens_brinde, itens_personalizados, forma_pagamento_parceiro, forma_envio_parceiro: dict,
-                 pedido_nota_fiscal, data_status: str = str(), cnpj_intermediador='', cnpj_instituicao_pagamento='', canal_site: str = '',
+                 pedido_nota_fiscal, data_entrega: str = str(), data_status: str = str(), cnpj_intermediador='', cnpj_instituicao_pagamento='', canal_site: str = '',
                  valor_adicional_forma_pagamento: float = 0.0, codigo_pedido_canal_alternativo: str = '', codigo_referencia: str = ''):
         self.order_id: int = id
         self.order_code: str = pedido_venda_id
@@ -86,7 +86,7 @@ class User:
 
 class Address:
     def __init__(self, cep: str, logradouro: str, numero: str, complemento: str, bairro: str, cidade: str,
-                 estado: str, pais: str, referencia: str, descricao: str, tipo_logradouro: str):
+                 estado: str, pais: str, referencia: str, descricao: str, tipo_logradouro: str, codigo_ibge: str = str()):
         self.zipcode: str = cep
         self.address_line: str = logradouro
         self.number: str = numero
