@@ -1,4 +1,4 @@
-
+from typing import List
 
 class CatalogoResponse:
     def __init__(self, Status: int, Message: str, codigo_erp: str = '', protocolo: str = '', loja: str = '') -> None:
@@ -10,7 +10,7 @@ class CatalogoResponse:
 
 
 class PriceResponse:
-    def __init__(self, codigo_erp, Status: int, Message: str, protocolo: str, loja: str):
+    def __init__(self, codigo_erp, Status, Message, protocolo, loja='', codigo_externo_campanha=''):
         self.codigo_erp = codigo_erp
         self.status = Status
         self.message = Message
@@ -26,4 +26,12 @@ class InvoiceResponse:
 class TrackingResponse:
     def __init__(self, Status: int, Message: str):
         self.status = Status
-        self.message = Message
\ No newline at end of file
+        self.message = Message
+
+
+class StockResponse:
+    def __init__(self, Identifiers, Status, Message, Protocolo):
+        self.identifiers: List[str] = Identifiers
+        self.status: int = Status
+        self.message: str = Message
+        self.protocol: str = Protocolo
