@@ -1,7 +1,7 @@
 import logging
 from datetime import datetime
 from time import sleep
-
+from src.entities.log import Log
 import src
 import src.api.okvendas as api_okvendas
 import src.database.connection as database
@@ -10,7 +10,8 @@ from src.database import queries
 from src.database.utils import DatabaseConfig
 from src.entities.tracking import Tracking
 from src.entities.invoice import Invoice
-from src.entities.order import Order
+from src.entities.order import Order, Queue
+from typing import List
 
 logger = logging.getLogger()
 
@@ -39,9 +40,9 @@ def job_orders(job_config: dict, start_at_pending: bool = False) -> None:
     try:
         db_config = utils.get_database_config(job_config)
         if start_at_pending:
-            process_order_queue(queue_status.get('pending'), db_config)
+            process_order_queue(queue_status.get('pending'), db_config, True)
 
-        process_order_queue(queue_status.get('paid'), db_config)
+        process_order_queue(queue_status.get('paid'), db_config, True)
 
         process_order_queue(queue_status.get('canceled'), db_config)
 
@@ -56,9 +57,6 @@ def job_orders(job_config: dict, start_at_pending: bool = False) -> None:
 
 
 def job_invoice_orders(job_config: dict):
-    # TODO Mudar para lógica de utilizar query com join no banco do cliente para consultar NFs
-    #   Add coluna na tabela pedido do semaforo para a data de sincronizacao da NF
-    #   Fazer o mesmo com o rastreio
     try:
         db_config = utils.get_database_config(job_config)
         if db_config.sql is None:
@@ -66,12 +64,15 @@ def job_invoice_orders(job_config: dict):
         else:
             invoices = query_invoices(db_config)
             for invoice in invoices:
-                invoice_sent = api_okvendas.post_invoices(src.client_data.get('url_api') + '/pedido/faturar', invoice, src.client_data.get('token_api'))
-                if invoice_sent is None:
-                    logger.info(job_config.get('job_name') + f' | NF do pedido {invoice.id} enviada com sucesso para api okvendas')
-                    continue
-                else:
-                    logger.error(job_config.get('job_name') + f' | Falha ao enviar NF do pedido {invoice.id} para api okvendas: {invoice_sent.message}')
+                try:
+                    invoice_sent = api_okvendas.post_invoices(src.client_data.get('url_api') + '/pedido/faturar', invoice, src.client_data.get('token_api'))
+                    if invoice_sent is None:
+                        logger.info(job_config.get('job_name') + f' | NF do pedido {invoice.id} enviada com sucesso para api okvendas')
+                        continue
+                    else:
+                        logger.error(job_config.get('job_name') + f' | Falha ao enviar NF do pedido {invoice.id} para api okvendas: {invoice_sent.message}')
+                except Exception as e:
+                    logger.error(job_config.get('job_name') + f' | Falha ao enviar NF do pedido {invoice.id}: {str(e)}')
     except Exception as e:
         logger.error(job_config.get('job_name') + f' | Falha na execução do job: {str(e)}')
 
@@ -84,18 +85,22 @@ def job_send_erp_tracking(job_config: dict):
         else:
             trackings = query_trackings(db_config)
             for tracking in trackings:
-                tracking_sent = api_okvendas.post_tracking(src.client_data.get('url_api') + '/pedido/encaminhar', tracking, src.client_data.get('token_api'))
-                if tracking_sent is None:
-                    logger.info(job_config.get('job_name') + f' | Rastreio do pedido {tracking.id} enviada com sucesso para api okvendas')
-                    continue
-                else:
-                    logger.error(job_config.get('job_name') + f' | Falha ao enviar rastreio do pedido {tracking.id} para api okvendas: {tracking_sent.message}')
+                try:
+                    tracking_sent = api_okvendas.post_tracking(src.client_data.get('url_api') + '/pedido/encaminhar', tracking, src.client_data.get('token_api'))
+                    if tracking_sent is None:
+                        logger.info(job_config.get('job_name') + f' | Rastreio do pedido {tracking.id} enviada com sucesso para api okvendas')
+                        continue
+                    else:
+                        logger.error(job_config.get('job_name') + f' | Falha ao enviar rastreio do pedido {tracking.id} para api okvendas: {tracking_sent.message}')
+                except Exception as e:
+                    logger.error(job_config.get('job_name') + f' | Falha ao enviar rastreio do pedido {tracking.id}: {str(e)}')
     except Exception as e:
         logger.error(job_config.get('job_name') + f' | Falha na execução do job: {str(e)}')
 
 
-def process_order_queue(status: str, db_config: DatabaseConfig) -> None:
+def process_order_queue(status: str, db_config: DatabaseConfig, status_to_insert: bool = False) -> None:
     try:
+        logger.info(current_job + f' | Consultando fila de pedidos no status {status}')
         queue = api_okvendas.get_order_queue(
             url=src.client_data.get('url_api') + '/pedido/fila/{0}',
             token=src.client_data.get('token_api'),
@@ -107,41 +112,62 @@ def process_order_queue(status: str, db_config: DatabaseConfig) -> None:
             try:
                 sleep(0.5)
                 qty = qty + 1
+                print()
                 logger.info(current_job + f' | Iniciando processamento ({qty} de {len(queue)}) pedido {q_order.order_id}')
                 order = api_okvendas.get_order(
                     url=src.client_data.get('url_api') + '/pedido/{0}',
                     token=src.client_data.get('token_api'),
                     order_id=q_order.order_id)
 
-                if order.erp_code is not None and order.erp_code != '':
+                if order.erp_code is not None and order.erp_code != '':  # Pedido integrado anteriormente
+
                     if check_order_existence(db_config, order.order_id):
                         logger.info(current_job + ' | Pedido ja integrado com o ERP, chamando procedure de atualizacao...')
                         if call_update_order_procedure(db_config, order):
                             logger.info(current_job + ' | Pedido atualizado com sucesso')
-                            protocol_order(db_config, order)
+                            protocol_order(db_config=db_config, order=order, queue_order=q_order, order_erp_id='', client_erp_id='')
                     else:
                         logger.warning(current_job + f' | Pedido {order.order_id} nao existe no banco semaforo porem ja foi integrado previamente. Protocolando pedido...')
-                        protocol_non_existent_order(order)
+                        protocol_non_existent_order(q_order)
 
-                else:
-                    logger.info(current_job + ' | Inserindo pedido no banco semaforo')
-                    inserted = insert_temp_order(order, db_config)
-                    if inserted:
-                        logger.info(current_job + ' | Pedido inserido com sucesso, chamando procedures...')
+                else:  # Pedido nao integrado anteriormente
+
+                    if check_order_existence(db_config, order.order_id):  # Pedido existente no banco semaforo
+
+                        logger.info(current_job + ' | Pedido já existente no banco semáforo, porem nao integrado com erp. Chamando procedures')
                         sp_success, client_erp_id, order_erp_id = call_order_procedures(db_config, q_order.order_id)
                         if sp_success:
                             logger.info(current_job + ' | Chamadas das procedures executadas com sucesso, protocolando pedido...')
-                            protocol_order(db_config, order, order_erp_id, client_erp_id)
+                            protocol_order(db_config=db_config, order=order, queue_order=q_order, order_erp_id=order_erp_id, client_erp_id=client_erp_id)
+
+                    elif status_to_insert:  # Pedido nao existe no semaforo e esta em status de internalizacao (pending e paid)
+
+                        logger.info(current_job + ' | Inserindo novo pedido no banco semaforo')
+                        inserted = insert_temp_order(order, db_config)
+                        if inserted:
+                            logger.info(current_job + ' | Pedido inserido com sucesso, chamando procedures...')
+                            sp_success, client_erp_id, order_erp_id = call_order_procedures(db_config, q_order.order_id)
+                            if sp_success:
+                                logger.info(current_job + ' | Chamadas das procedures executadas com sucesso, protocolando pedido...')
+                                protocol_order(db_config=db_config, order=order, queue_order=q_order, order_erp_id=order_erp_id, client_erp_id=client_erp_id)
+
+                    else:  # Pedido nao existe no semaforo e nao esta em status de internalizacao (pending e paid)
+                        logger.warning(current_job + ' | Pedido nao existente no banco semaforo e nao se encontra em status de internalizacao')
+
             except Exception as e:
                 logger.error(current_job + f' | Erro no processamento do pedido {q_order.order_id}: {str(e)}')
+                api_okvendas.post_log(Log(current_job + f' | Erro no processamento do pedido {q_order.order_id}: {str(e)}', datetime.now().isoformat(), str(q_order.order_id), 'PEDIDO'))
     except Exception as e:
         logger.error(current_job + f' | Erro ao inicializar job de processamento de pedidos: {str(e)}')
+        api_okvendas.post_log(Log(current_job + f' | Erro ao inicializar job de processamento de pedidos do status {status}: {str(e)}', datetime.now().isoformat(), status, 'PEDIDO'))
 
 
-def protocol_order(db_config: DatabaseConfig, order: Order, order_erp_id: str = '', client_erp_id: str = '') -> None:
+def protocol_order(db_config: DatabaseConfig, order: Order, queue_order: Queue, order_erp_id: str = '', client_erp_id: str = '') -> None:
     db = database.Connection(db_config)
     try:
+        print()
         if order_erp_id != '':
+            logger.info(current_job + f' | Protocolando pedido com codigo_referencia {order_erp_id}')
             updated_order_code = api_okvendas.put_order_erp_code(src.client_data.get('url_api') + '/pedido/integradoERP',
                                                                  src.client_data.get('token_api'),
                                                                  order.order_id,
@@ -151,7 +177,9 @@ def protocol_order(db_config: DatabaseConfig, order: Order, order_erp_id: str =
             else:
                 logger.warning(current_job + ' | Falha ao atualizar o Codigo Erp do pedido via api OkVendas')
 
+        print()
         if client_erp_id != '':
+            logger.info(current_job + f' | Protocolando cliente com codigo_referencia {client_erp_id}')
             updated_client_code = api_okvendas.put_client_erp_code(src.client_data.get('url_api') + '/cliente/codigo',
                                                                    src.client_data.get('token_api'),
                                                                    {
@@ -163,7 +191,9 @@ def protocol_order(db_config: DatabaseConfig, order: Order, order_erp_id: str =
             else:
                 logger.warning(current_job + ' | Falha ao atualizar o Codigo Erp do cliente via api OkVendas')
 
-        protocoled_order = api_okvendas.put_protocol_orders(order.order_id)
+        print()
+        logger.info(current_job + f' | Removendo pedido da fila pelo protocolo {queue_order.protocol}')
+        protocoled_order = api_okvendas.put_protocol_orders([queue_order.protocol])
         if protocoled_order:
             logger.info(current_job + ' | Pedido protocolado via api OkVendas')
         else:
@@ -177,18 +207,20 @@ def protocol_order(db_config: DatabaseConfig, order: Order, order_erp_id: str =
         conn.commit()
         conn.close()
     except Exception as e:
-        logger.error(f'Erro ao protocolar pedidos: {e}')
+        logger.error(current_job + f' | Erro ao protocolar pedidos: {e}')
+        api_okvendas.post_log(Log(current_job + f' | Erro ao protocolar pedido {queue_order.order_id}: {str(e)}', datetime.now().isoformat(), str(queue_order.order_id), 'PEDIDO'))
 
 
-def protocol_non_existent_order(order: Order) -> None:
+def protocol_non_existent_order(queue_order: Queue) -> None:
     try:
-        protocoled_order = api_okvendas.put_protocol_orders(order.order_id)
+        protocoled_order = api_okvendas.put_protocol_orders([queue_order.protocol])
         if protocoled_order:
-            logger.info(current_job + f' | Pedido {order.order_id} protocolado via api OkVendas')
+            logger.info(current_job + f' | Pedido {queue_order.order_id} protocolado via api OkVendas')
         else:
-            logger.warning(current_job + f' | Falha ao protocolar pedido {order.order_id} via api OkVendas')
+            logger.warning(current_job + f' | Falha ao protocolar pedido {queue_order.order_id} via api OkVendas')
     except Exception as ex:
-        logger.error(f'Erro ao protocolar pedido {order.order_id}: {str(ex)}')
+        logger.error(current_job + f' | Erro ao protocolar pedido {queue_order.order_id}: {str(ex)}')
+        api_okvendas.post_log(Log(current_job + f' | Erro ao protocolar pedido {queue_order.order_id}: {str(ex)}', datetime.now().isoformat(), str(queue_order.order_id), 'PEDIDO'))
 
 
 def insert_temp_order(order: Order, db_config: DatabaseConfig) -> bool:
@@ -199,37 +231,63 @@ def insert_temp_order(order: Order, db_config: DatabaseConfig) -> bool:
         step = 'conexao'
         cursor = conn.cursor()
 
-        # insere cliente
-        step = 'insere cliente'
-        logger.info(f'\tPedido {order.order_id}: Inserindo cliente')
-        cursor.execute(queries.get_insert_client_command(db_config.db_type), queries.get_command_parameter(db_config.db_type, [
-            order.user.name,
-            order.user.company_name,
-            order.user.cpf,
-            order.user.cnpj,
-            order.user.email,
-            order.user.residential_phone,
-            order.user.mobile_phone,
-            order.user.address.zipcode,
-            order.user.address.address_type,
-            order.user.address.address_line,
-            order.user.address.number,
-            order.user.address.complement,
-            order.user.address.neighbourhood,
-            order.user.address.city,
-            order.user.address.state,
-            order.user.address.reference]))
+        if order.user.erp_code is not None and order.user.erp_code != '':
+            cursor.execute(queries.get_query_client_erp(db_config.db_type), queries.get_command_parameter(db_config.db_type, [order.user.erp_code]))
+            existent_client = cursor.fetchone()
+            if existent_client is None:
+                # insere cliente
+                step = 'insere cliente'
+                logger.info(f'\tPedido {order.order_id}: Inserindo cliente')
+                cursor.execute(queries.get_insert_client_command(db_config.db_type), queries.get_command_parameter(db_config.db_type, [
+                    order.user.name or order.user.company_name,
+                    order.user.company_name or order.user.name,
+                    order.user.cpf,
+                    order.user.cnpj,
+                    order.user.email,
+                    order.user.residential_phone,
+                    order.user.mobile_phone,
+                    order.user.address.zipcode,
+                    order.user.address.address_type,
+                    order.user.address.address_line,
+                    order.user.address.number,
+                    order.user.address.complement,
+                    order.user.address.neighbourhood or " ",
+                    order.user.address.city,
+                    order.user.address.state,
+                    order.user.address.reference]))
+            else:
+                # update no cliente existente
+                step = 'update cliente'
+                logger.info(f'\tPedido {order.order_id}: Atualizando cliente existente')
+                cursor.execute(queries.get_update_client_sql(db_config.db_type), queries.get_command_parameter(db_config.db_type, [
+                    order.user.name,
+                    order.user.company_name or order.user.name,
+                    order.user.cpf,
+                    order.user.cnpj,
+                    order.user.email,
+                    order.user.residential_phone,
+                    order.user.mobile_phone,
+                    order.user.address.zipcode,
+                    order.user.address.address_type,
+                    order.user.address.address_line,
+                    order.user.address.number,
+                    order.user.address.complement,
+                    order.user.address.neighbourhood,
+                    order.user.address.city,
+                    order.user.address.state,
+                    order.user.address.reference,
+                    order.user.erp_code]))
 
-        if cursor.rowcount > 0:
-            logger.info(current_job + f' | Cliente inserido para o pedido {order.order_id}')
-            cursor.execute(queries.get_query_client(db_config.db_type), queries.get_command_parameter(db_config.db_type, [order.user.email]))
-            client_id = cursor.fetchone()
-            if client_id is None:
+            if cursor.rowcount > 0:
+                logger.info(current_job + f' | Cliente inserido/atualizado para o pedido {order.order_id}')
+                cursor.execute(queries.get_query_client(db_config.db_type), queries.get_command_parameter(db_config.db_type, [order.user.email]))
+                (client_id, ) = cursor.fetchone()
+                if client_id is None or client_id <= 0:
+                    cursor.close()
+                    raise Exception('Nao foi possivel obter o cliente inserido do banco de dados')
+            else:
                 cursor.close()
-                raise Exception('Nao foi possivel obter o cliente inserido do banco de dados')
-        else:
-            cursor.close()
-            raise Exception('O cliente nao foi inserido')
+                raise Exception('O cliente nao foi inserido')
 
         # insere pedido
         step = 'insere pedido'
@@ -237,28 +295,29 @@ def insert_temp_order(order: Order, db_config: DatabaseConfig) -> bool:
         cursor.execute(queries.get_insert_order_command(db_config.db_type), queries.get_command_parameter(db_config.db_type, [
             order.order_id,
             order.order_code,
-            str(datetime.strptime(order.date.replace('T', ' '), '%Y-%m-%d %H:%M:%S')),
+            str(datetime.strptime(order.date.replace('T', ' '), '%Y-%m-%d %H:%M:%S') if order.date is not None else ''),
             order.status,
-            client_id[0],
+            client_id,
             order.total_amount,
             order.total_discount,
             order.freight_amount,
             order.additional_payment_amount,
-            str(datetime.strptime(order.paid_date.replace('T', ' '), '%Y-%m-%d %H:%M:%S')),
+            str(datetime.strptime(order.paid_date.replace('T', ' '), '%Y-%m-%d %H:%M:%S') if order.paid_date is not None else ''),
             order.payment_type,
             order.flag,
             order.parcels,
             order.erp_payment_condition,
             order.tracking_code,
-            str(datetime.strptime(order.delivery_forecast.replace('T', ' '), '%Y-%m-%d %H:%M:%S')),
+            str(datetime.strptime(order.delivery_forecast.replace('T', ' '), '%Y-%m-%d %H:%M:%S') if order.delivery_forecast is not None else ''),
             order.carrier,
-            order.shipping_mode]))
+            order.shipping_mode,
+            order.channel_id]))
 
         if cursor.rowcount > 0:
             logger.info(current_job + f' | Pedido {order.order_id} inserido')
             cursor.execute(queries.get_query_order(db_config.db_type), queries.get_command_parameter(db_config.db_type, [order.order_id]))
-            order_id = cursor.fetchone()
-            if order_id is None:
+            (order_id, ) = cursor.fetchone()
+            if order_id is None or order_id <= 0:
                 cursor.close()
                 raise Exception('Nao foi possivel obter o pedido inserido no banco de dados')
         else:
@@ -267,10 +326,10 @@ def insert_temp_order(order: Order, db_config: DatabaseConfig) -> bool:
 
         # insere itens
         step = 'insere itens'
-        logger.info(f'\tPedido {order.order_id}: Inserindo itens do pedido')
+        logger.info(f'\tPedido {order.order_id} com id semaforo {order_id}: Inserindo itens do pedido')
         for item in order.items:
             cursor.execute(queries.get_insert_order_items_command(db_config.db_type), queries.get_command_parameter(db_config.db_type, [
-                order.order_id,
+                order_id,
                 item.sku,
                 item.erp_code,
                 item.quantity,
@@ -285,6 +344,7 @@ def insert_temp_order(order: Order, db_config: DatabaseConfig) -> bool:
         return True
     except Exception as e:
         logger.error(current_job + f' | Passo {step} - Erro durante a inserção dos dados do pedido {order.order_id}: {str(e)}')
+        api_okvendas.post_log(Log(current_job + f' | Passo {step} - Erro durante a inserção dos dados do pedido {order.order_id}: {str(e)}', datetime.now().isoformat(), str(order.order_id), 'PEDIDO'))
         conn.rollback()
         conn.close()
         return False
@@ -298,15 +358,26 @@ def call_order_procedures(db_config: DatabaseConfig, order_id: int) -> (bool, st
     conn = db.get_conect()
     try:
         cursor = conn.cursor()
+        logger.info(current_job + f' | Executando procedure de cliente')
+        if db_config.is_sql_server():
+            cursor.execute('exec openk_semaforo.sp_processa_cliente @pedido = ?', order_id)
+            (client_erp_id, ) = cursor.fetchone()
+        elif db_config.is_oracle() or db_config.is_mysql():
+            client_out_value = cursor.var(str)
+            cursor.callproc('OPENK_SEMAFORO.SP_PROCESSA_CLIENTE', [order_id, client_out_value])
+            client_erp_id = client_out_value.getvalue()
 
-        client_out_value = cursor.var(str)
-        cursor.callproc('OPENK_SEMAFORO.SP_PROCESSA_CLIENTE', [order_id, client_out_value])
-        client_erp_id = client_out_value.getvalue()
         if client_erp_id is not None:
             logger.info(current_job + f' | Cliente ERP criado com sucesso {client_erp_id}')
-            order_out_value = cursor.var(str)
-            cursor.callproc('OPENK_SEMAFORO.SP_PROCESSA_PEDIDO', [order_id, order_out_value])
-            order_erp_id = order_out_value.getvalue()
+            logger.info(current_job + f' | Executando procedure de pedido')
+            if db_config.is_sql_server():
+                cursor.execute('exec openk_semaforo.sp_processa_pedido @pedido = ?', order_id)
+                (order_erp_id,) = cursor.fetchone()
+            elif db_config.is_oracle() or db_config.is_mysql():
+                order_out_value = cursor.var(str)
+                cursor.callproc('OPENK_SEMAFORO.SP_PROCESSA_PEDIDO', [order_id, int(client_erp_id), order_out_value])
+                order_erp_id = order_out_value.getvalue()
+
             if order_erp_id is not None:
                 logger.info(current_job + f' | Pedido ERP criado com sucesso {order_erp_id}')
             else:
@@ -325,6 +396,7 @@ def call_order_procedures(db_config: DatabaseConfig, order_id: int) -> (bool, st
         return success, client_erp_id, order_erp_id
     except Exception as e:
         logger.error(current_job + f' | Erro: {e}')
+        api_okvendas.post_log(Log(current_job + f' | Erro no método de chamada da procedure de internalização do pedido {order_id}: {str(e)}', datetime.now().isoformat(), str(order_id), 'PEDIDO'))
         conn.rollback()
         conn.close()
 
@@ -335,9 +407,14 @@ def call_update_order_procedure(db_config: DatabaseConfig, order: Order) -> bool
     conn = db.get_conect()
     try:
         cursor = conn.cursor()
-        order_updated = cursor.var(int)
-        cursor.callproc('OPENK_SEMAFORO.SP_ATUALIZA_PEDIDO', [order.order_id, order.status, order_updated])
-        updated = order_updated.getvalue()
+        updated: bool = False
+        if db_config.is_sql_server():
+            cursor.execute('exec openk_semaforo.sp_atualiza_pedido @pedido = ?', order.order_id)
+            (updated, ) = cursor.fetchone()
+        elif db_config.is_oracle() or db_config.is_mysql():
+            order_updated = cursor.var(int)
+            cursor.callproc('OPENK_SEMAFORO.SP_ATUALIZA_PEDIDO', [order.order_id, order.status, order_updated])
+            updated = order_updated.getvalue()
         if updated is None or updated <= 0:
             success = False
             logger.warning(current_job + f' | Nao foi possivel atualizar o pedido informado')
@@ -351,6 +428,7 @@ def call_update_order_procedure(db_config: DatabaseConfig, order: Order) -> bool
         return success
     except Exception as e:
         logger.error(current_job + f' | Erro: {e}')
+        api_okvendas.post_log(Log(current_job + f' | Erro no método de chamada da procedure de atualização do pedido {order.order_id}: {str(e)}', datetime.now().isoformat(), str(order.order_id), 'PEDIDO'))
         conn.rollback()
         conn.close()
 
@@ -370,7 +448,7 @@ def check_order_existence(db_config: DatabaseConfig, order_id: int) -> bool:
         return False
 
 
-def query_invoices(db_config: DatabaseConfig) -> list[Invoice]:
+def query_invoices(db_config: DatabaseConfig) -> List[Invoice]:
     """
     Consulta as notas fiscais a serem enviadas na api do okvendas
     Args:
@@ -382,7 +460,7 @@ def query_invoices(db_config: DatabaseConfig) -> list[Invoice]:
     db = database.Connection(db_config)
     conn = db.get_conect()
     cursor = conn.cursor()
-    invoices = list[Invoice]
+    invoices = List[Invoice]
     try:
         cursor.execute(db_config.sql.replace(';', ''))
         rows = cursor.fetchall()
@@ -399,7 +477,7 @@ def query_invoices(db_config: DatabaseConfig) -> list[Invoice]:
     return invoices
 
 
-def query_trackings(db_config: DatabaseConfig) -> list[Tracking]:
+def query_trackings(db_config: DatabaseConfig) -> List[Tracking]:
     """
     Consulta os rastreios a serem enviados na api do okvendas
     Args:
@@ -411,7 +489,7 @@ def query_trackings(db_config: DatabaseConfig) -> list[Tracking]:
     db = database.Connection(db_config)
     conn = db.get_conect()
     cursor = conn.cursor()
-    trackings = list[Tracking]
+    trackings = List[Tracking]
     try:
         cursor.execute(db_config.sql.replace(';', ''))
         rows = cursor.fetchall()
@@ -426,3 +504,4 @@ def query_trackings(db_config: DatabaseConfig) -> list[Tracking]:
         logger.error(f' Erro ao consultar rastreios no banco: {ex}')
 
     return trackings
+
